Error

Enum Error 

pub enum Error {
    Short,
    BadFlag(u8),
    BadKind(u8),
    TooMuchPadding(u8),
    PayloadLengthTooShort,
    PartialSettingLength,
    InvalidPayloadLength,
}
Errors that can occur during parsing an HTTP/2 frame.

Variants



Short

A full frame header was not passed.



BadFlag(u8)

An unsupported value was set for the flag value.



BadKind(u8)

An unsupported value was set for the frame kind.



TooMuchPadding(u8)

The padding length was larger than the frame-header-specified length of the payload.



PayloadLengthTooShort

The payload length specified by the frame header was shorter than necessary for the parser settings specified and the frame type.

This happens if, for instance, the priority flag is set and the header length is shorter than a stream dependency.

PayloadLengthTooShort should be treated as a protocol error.



PartialSettingLength

The payload length specified by the frame header of a settings frame was not a round multiple of the size of a single setting.



InvalidPayloadLength

The payload length specified by the frame header was not the value necessary for the specific frame type.